==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/de/da1/gfx_8cpp.js <==
var gfx_8cpp =
[
    [ "EXTR", "de/da1/gfx_8cpp.html#a48cf4b00c945d9c34fcbbca05dc27408", null ],
    [ "EXTR2", "de/da1/gfx_8cpp.html#a729b45612a6ad4676ebd81c9ad210f8f", null ],
    [ "ChangeResInGame", "de/da1/gfx_8cpp.html#a353daa7c0bb8809d913cf585dd7622e7", null ],
    [ "compare_res", "de/da1/gfx_8cpp.html#a3507ee5b15a37b648dd9b9f9213650d8", null ],
    [ "CursorTick", "de/da1/gfx_8cpp.html#a21b47af832d17183a571d33709eb4ca4", null ],
    [ "DoPaletteAnimations", "de/da1/gfx_8cpp.html#aa7eeb2ba0e5517177361c20f54831e58", null ],
    [ "DrawBox", "de/da1/gfx_8cpp.html#adcea9bd22fff70a074b68f66ef028aff", null ],
    [ "DrawCharCentered", "de/da1/gfx_8cpp.html#a53ad0b488a77ab282c23502757739cef", null ],
    [ "DrawDirtyBlocks", "de/da1/gfx_8cpp.html#a82dbdab183007a06f3319f7e7e44d132", null ],
    [ "DrawLayoutLine", "de/da1/gfx_8cpp.html#a5dae3df60000b244231089174c660b9b", null ],
    [ "DrawMouseCursor", "de/da1/gfx_8cpp.html#a7474f42828d5ea48e4a7793cc1d63823", null ],
    [ "DrawSprite", "de/da1/gfx_8cpp.html#a851880c4ae8c3a405ff13cedb799ccf6", null ],
    [ "DrawSpriteViewport", "de/da1/gfx_8cpp.html#aa38c87d18d8e8ca65879172cd2b411bd", null ],
    [ "DrawString", "de/da1/gfx_8cpp.html#aa5d4fd711ccea899530f3bc9c067e200", null ],
    [ "DrawString", "de/da1/gfx_8cpp.html#a140803e68a9fc91b0531f63ba55c2010", null ],
    [ "DrawStringMultiLine", "de/da1/gfx_8cpp.html#a1d725c53092838bb2a602ff8f1dd9161", null ],
    [ "DrawStringMultiLine", "de/da1/gfx_8cpp.html#a2fa58b4c057e5124236d1ccef46f5cce", null ],
    [ "FillDrawPixelInfo", "de/da1/gfx_8cpp.html#aea9706a3f0deee7c415df4bcd4bbd243", null ],
    [ "GetBlitterMode", "de/da1/gfx_8cpp.html#a5a135947b53dfdc123d1282f70ceb6de", null ],
    [ "GetBroadestDigit", "de/da1/gfx_8cpp.html#a08ad6a211b44b4bd2380a0e9aa59aef5", null ],
    [ "GetCharacterWidth", "de/da1/gfx_8cpp.html#ab7446c312745b77ad3bf4073d7135c43", null ],
    [ "GetCharAtPosition", "de/da1/gfx_8cpp.html#a022733b4aef3c5c0b3412189cb7d940d", null ],
    [ "GetCharPosInString", "de/da1/gfx_8cpp.html#a597c10e8b6b6ad70de5e9abd50197758", null ],
    [ "GetContrastColour", "de/da1/gfx_8cpp.html#a92527419c1bdf1d2ed7b010eb7ddb301", null ],
    [ "GetDigitWidth", "de/da1/gfx_8cpp.html#a8a3946c4bf69c3c5b841dc7f0652aa94", null ],
    [ "GetSpriteSize", "de/da1/gfx_8cpp.html#a0adc361afb536668f4f6c749607185f3", null ],
    [ "GetStringBoundingBox", "de/da1/gfx_8cpp.html#a9553fc0e757946bccbf505aecbfff919", null ],
    [ "GetStringBoundingBox", "de/da1/gfx_8cpp.html#a7bc77418c11174e17dceaa9c279d3423", null ],
    [ "GetStringHeight", "de/da1/gfx_8cpp.html#ab4bdc36ce47a9d700b1b55b28aef51b6", null ],
    [ "GetStringHeight", "de/da1/gfx_8cpp.html#ac7aaeb816ab4f8f3cdf11e55d7603cc2", null ],
    [ "GetStringLineCount", "de/da1/gfx_8cpp.html#a39ed16837962bcfdef87e98f97df84b9", null ],
    [ "GetStringMultiLineBoundingBox", "de/da1/gfx_8cpp.html#ab8a303b48a03621231a4682580bbf6f8", null ],
    [ "GetStringMultiLineBoundingBox", "de/da1/gfx_8cpp.html#a07bf77588ca7fafb6339af33098483d0", null ],
    [ "GfxBlitter", "de/da1/gfx_8cpp.html#adcddd0a7ae0fc0201dc52b4843b0e1fe", null ],
    [ "GfxDoDrawLine", "de/da1/gfx_8cpp.html#ae17b832b6a815b04926e5b12afbe7d9c", null ],
    [ "GfxDrawLine", "de/da1/gfx_8cpp.html#abd70d45a5545cc6855100bde0947bb77", null ],
    [ "GfxDrawLineUnscaled", "de/da1/gfx_8cpp.html#ab88f76a142c04fb3ee1a4629ce958722", null ],
    [ "GfxFillRect", "de/da1/gfx_8cpp.html#a7299b610680227ca86115b1eb3aee677", null ],
    [ "GfxInitPalettes", "de/da1/gfx_8cpp.html#a447580145f88c4c8a962cc7299eb542d", null ],
    [ "GfxMainBlitter", "de/da1/gfx_8cpp.html#aff0ecd64fe86906cac1f0c4cafb269c8", null ],
    [ "GfxMainBlitterViewport", "de/da1/gfx_8cpp.html#a33c8de5002684fa5521e877468f91b36", null ],
    [ "GfxPreprocessLine", "de/da1/gfx_8cpp.html#ab83a44fdbbdc5e95b793a63777fb4a6e", null ],
    [ "GfxScroll", "de/da1/gfx_8cpp.html#a580ce1d1be3c10f10e279c628d5e7a5e", null ],
    [ "LoadStringWidthTable", "de/da1/gfx_8cpp.html#a62ff1c222d23d5fc80ea9d24ddc25edc", null ],
    [ "MarkWholeScreenDirty", "d5/d48/group__dirty.html#ga94c77ddf45ec98384625cba512034f24", null ],
    [ "RedrawScreenRect", "de/da1/gfx_8cpp.html#aa02472750c233df959585e724fba4f3b", null ],
    [ "ScreenSizeChanged", "de/da1/gfx_8cpp.html#ac686351aa68925988c7537e19ec2cfef", null ],
    [ "SetAnimatedMouseCursor", "de/da1/gfx_8cpp.html#ab60eb5eb0a0ae49d3fb1a868faf85d34", null ],
    [ "SetColourRemap", "de/da1/gfx_8cpp.html#a46de37429ce642a83f42e90baed0d28e", null ],
    [ "SetCursorSprite", "de/da1/gfx_8cpp.html#a0bd1ab0850cbf41f4d9ee48d8b3c9548", null ],
    [ "SetDirtyBlocks", "de/da1/gfx_8cpp.html#afd8f980a4f4bc6ff0331e5d5b1c72bd3", null ],
    [ "SetMouseCursor", "de/da1/gfx_8cpp.html#a0811d7d737e294a66db123e186af6ca0", null ],
    [ "SetMouseCursorBusy", "de/da1/gfx_8cpp.html#a607951b4f6911cdaa8d38b14d4c07c78", null ],
    [ "SortResolutions", "de/da1/gfx_8cpp.html#ab09a58c48b60658e5c7e638826ccc0d5", null ],
    [ "SwitchAnimatedCursor", "de/da1/gfx_8cpp.html#afa772a8747496fc2e38cefe3bffd0bde", null ],
    [ "ToggleFullScreen", "de/da1/gfx_8cpp.html#a6c3d71aef57b8889c19026e91f0d4e2d", null ],
    [ "UndrawMouseCursor", "de/da1/gfx_8cpp.html#a0d13104b28e8889179ecb96896f6e1a5", null ],
    [ "UpdateCursorSize", "de/da1/gfx_8cpp.html#a0ba5acdd2730490e8ea3f8485854dfe9", null ],
    [ "_colour_gradient", "de/da1/gfx_8cpp.html#a04e67e52c36bcf9ad6d879494e6b3e2e", null ],
    [ "_colour_remap_ptr", "de/da1/gfx_8cpp.html#a95af7cf3ee5f77e8428449f648e324f3", null ],
    [ "_ctrl_pressed", "de/da1/gfx_8cpp.html#a449ad8ebe1b8f9b4eda3293236fba396", null ],
    [ "_cur_dpi", "de/da1/gfx_8cpp.html#a29b83a34f3f8b1f99d094cd8f4a9dc30", null ],
    [ "_cur_palette", "de/da1/gfx_8cpp.html#a82b91ff60054612cf4344e43ae7923e2", null ],
    [ "_cursor", "de/da1/gfx_8cpp.html#a7b055b3dc8a5c15896a6ac0f0f6499c2", null ],
    [ "_cursor_backup", "de/da1/gfx_8cpp.html#aafd8913569ba03aaf6fe309d7c8f2375", null ],
    [ "_dirkeys", "de/da1/gfx_8cpp.html#a52f15585b6bfb0944c9e6d2610069623", null ],
    [ "_dirty_block_colour", "de/da1/gfx_8cpp.html#a9d43a3f183315e122cf5258dd4872406", null ],
    [ "_dirty_blocks", "de/da1/gfx_8cpp.html#ab050ce6e94522e5e2a8521e1267d9bd6", null ],
    [ "_dirty_bytes_per_line", "de/da1/gfx_8cpp.html#a3ba304a6116ae401357dee224ba70888", null ],
    [ "_exit_game", "de/da1/gfx_8cpp.html#a7eb0d14ae569ca0992df5214cd0b249c", null ],
    [ "_fast_forward", "de/da1/gfx_8cpp.html#af6d3cc28b3e6a11938d0c828b6c3bb64", null ],
    [ "_fullscreen", "de/da1/gfx_8cpp.html#af41afe2d8abf7062f7aae1ae5e4dca26", null ],
    [ "_game_mode", "de/da1/gfx_8cpp.html#a5f7525568d0b37fb0b60f52154db6b1b", null ],
    [ "_gui_zoom", "de/da1/gfx_8cpp.html#ad6b6d984ea0f9aef53e2f84fd3e04fdf", null ],
    [ "_invalid_rect", "d5/d48/group__dirty.html#ga160b895629d19b4f7b532867d6c5eee8", null ],
    [ "_left_button_clicked", "de/da1/gfx_8cpp.html#a4f91b925a590a5658a6175d77b31c4fd", null ],
    [ "_left_button_down", "de/da1/gfx_8cpp.html#a29528c503a35cad849e24c62ccf54a2f", null ],
    [ "_pause_mode", "de/da1/gfx_8cpp.html#afdd79e14e419f125b43346bbe5a5b132", null ],
    [ "_right_button_clicked", "de/da1/gfx_8cpp.html#a85547be96d2332331ca3386e66047398", null ],
    [ "_right_button_down", "de/da1/gfx_8cpp.html#aebb077b0ea0663869f537b974ef3c858", null ],
    [ "_screen", "de/da1/gfx_8cpp.html#aee3b2caf656df1c9e875f33841c8cf7f", null ],
    [ "_screen_disable_anim", "de/da1/gfx_8cpp.html#a4c49532bf3116616eab958b49c7cbbc0", null ],
    [ "_shift_pressed", "de/da1/gfx_8cpp.html#a15077a1979b5abe1e4cf850f392d37cb", null ],
    [ "_string_colourremap", "de/da1/gfx_8cpp.html#a77f0c7c5b9db2ee5a4fca2c5d4e8ebee", null ],
    [ "_stringwidth_table", "de/da1/gfx_8cpp.html#ac37ee46cc4d3dbe8eb25f0bd9df74bf9", null ],
    [ "_support8bpp", "de/da1/gfx_8cpp.html#a45bc881191b074f1a65f29bfc14de611", null ],
    [ "_switch_mode", "de/da1/gfx_8cpp.html#aca417dc75c3ef57541db809c4664cf74", null ],
    [ "DIRTY_BLOCK_HEIGHT", "de/da1/gfx_8cpp.html#ad8794f9ea40de26aa84406378dfd4110", null ],
    [ "DIRTY_BLOCK_WIDTH", "de/da1/gfx_8cpp.html#ac416df3b69ab1ab6b0dc0a6af5fd2b70", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/de/da1/gfx_8cpp.js <==
var gfx_8cpp =
[
    [ "EXTR", "de/da1/gfx_8cpp.html#a48cf4b00c945d9c34fcbbca05dc27408", null ],
    [ "EXTR2", "de/da1/gfx_8cpp.html#a729b45612a6ad4676ebd81c9ad210f8f", null ],
    [ "LineSegment", "de/da1/gfx_8cpp.html#aab6de9aed86c58a273b64cf038a0faf3", null ],
    [ "AddDirtyBlock", "d5/d48/group__dirty.html#ga7e4302308faee4876d5d826b2e9714a0", null ],
    [ "ChangeResInGame", "de/da1/gfx_8cpp.html#a353daa7c0bb8809d913cf585dd7622e7", null ],
    [ "CursorTick", "de/da1/gfx_8cpp.html#a21b47af832d17183a571d33709eb4ca4", null ],
    [ "DoPaletteAnimations", "de/da1/gfx_8cpp.html#aa7eeb2ba0e5517177361c20f54831e58", null ],
    [ "DrawBox", "de/da1/gfx_8cpp.html#adcea9bd22fff70a074b68f66ef028aff", null ],
    [ "DrawCharCentered", "de/da1/gfx_8cpp.html#a53ad0b488a77ab282c23502757739cef", null ],
    [ "DrawDirtyBlocks", "d5/d48/group__dirty.html#ga82dbdab183007a06f3319f7e7e44d132", null ],
    [ "DrawLayoutLine", "de/da1/gfx_8cpp.html#a868b107b1d17fdf2d2da9e584d38c2e2", null ],
    [ "DrawMouseCursor", "de/da1/gfx_8cpp.html#a7474f42828d5ea48e4a7793cc1d63823", null ],
    [ "DrawSprite", "de/da1/gfx_8cpp.html#a851880c4ae8c3a405ff13cedb799ccf6", null ],
    [ "DrawSpriteViewport", "de/da1/gfx_8cpp.html#aa38c87d18d8e8ca65879172cd2b411bd", null ],
    [ "DrawString", "de/da1/gfx_8cpp.html#aa5d4fd711ccea899530f3bc9c067e200", null ],
    [ "DrawString", "de/da1/gfx_8cpp.html#a140803e68a9fc91b0531f63ba55c2010", null ],
    [ "DrawStringMultiLine", "de/da1/gfx_8cpp.html#a1d725c53092838bb2a602ff8f1dd9161", null ],
    [ "DrawStringMultiLine", "de/da1/gfx_8cpp.html#a2fa58b4c057e5124236d1ccef46f5cce", null ],
    [ "FillDrawPixelInfo", "de/da1/gfx_8cpp.html#aea9706a3f0deee7c415df4bcd4bbd243", null ],
    [ "GetBlitterMode", "de/da1/gfx_8cpp.html#a5a135947b53dfdc123d1282f70ceb6de", null ],
    [ "GetBroadestDigit", "de/da1/gfx_8cpp.html#a08ad6a211b44b4bd2380a0e9aa59aef5", null ],
    [ "GetCharacterWidth", "de/da1/gfx_8cpp.html#ab7446c312745b77ad3bf4073d7135c43", null ],
    [ "GetCharAtPosition", "de/da1/gfx_8cpp.html#a022733b4aef3c5c0b3412189cb7d940d", null ],
    [ "GetCharPosInString", "de/da1/gfx_8cpp.html#a597c10e8b6b6ad70de5e9abd50197758", null ],
    [ "GetContrastColour", "de/da1/gfx_8cpp.html#a92527419c1bdf1d2ed7b010eb7ddb301", null ],
    [ "GetDigitWidth", "de/da1/gfx_8cpp.html#a8a3946c4bf69c3c5b841dc7f0652aa94", null ],
    [ "GetSpriteSize", "de/da1/gfx_8cpp.html#a0adc361afb536668f4f6c749607185f3", null ],
    [ "GetStringBoundingBox", "de/da1/gfx_8cpp.html#a9553fc0e757946bccbf505aecbfff919", null ],
    [ "GetStringBoundingBox", "de/da1/gfx_8cpp.html#a7bc77418c11174e17dceaa9c279d3423", null ],
    [ "GetStringHeight", "de/da1/gfx_8cpp.html#ab4bdc36ce47a9d700b1b55b28aef51b6", null ],
    [ "GetStringHeight", "de/da1/gfx_8cpp.html#ac7aaeb816ab4f8f3cdf11e55d7603cc2", null ],
    [ "GetStringLineCount", "de/da1/gfx_8cpp.html#a39ed16837962bcfdef87e98f97df84b9", null ],
    [ "GetStringMultiLineBoundingBox", "de/da1/gfx_8cpp.html#a07bf77588ca7fafb6339af33098483d0", null ],
    [ "GetStringMultiLineBoundingBox", "de/da1/gfx_8cpp.html#ab8a303b48a03621231a4682580bbf6f8", null ],
    [ "GfxBlitter", "de/da1/gfx_8cpp.html#adcddd0a7ae0fc0201dc52b4843b0e1fe", null ],
    [ "GfxDoDrawLine", "de/da1/gfx_8cpp.html#ae17b832b6a815b04926e5b12afbe7d9c", null ],
    [ "GfxDrawLine", "de/da1/gfx_8cpp.html#abd70d45a5545cc6855100bde0947bb77", null ],
    [ "GfxDrawLineUnscaled", "de/da1/gfx_8cpp.html#ab88f76a142c04fb3ee1a4629ce958722", null ],
    [ "GfxFillPolygon", "de/da1/gfx_8cpp.html#a001751743e8b6685f0e4f09f1a8748d2", null ],
    [ "GfxFillRect", "de/da1/gfx_8cpp.html#a7299b610680227ca86115b1eb3aee677", null ],
    [ "GfxInitPalettes", "de/da1/gfx_8cpp.html#a447580145f88c4c8a962cc7299eb542d", null ],
    [ "GfxMainBlitter", "de/da1/gfx_8cpp.html#a1d06a24a132efa21889f6333ab54b176", null ],
    [ "GfxMainBlitterViewport", "de/da1/gfx_8cpp.html#a239a96b1ef6b415499ac1d4ba87d1af7", null ],
    [ "GfxPreprocessLine", "de/da1/gfx_8cpp.html#ab83a44fdbbdc5e95b793a63777fb4a6e", null ],
    [ "GfxScroll", "de/da1/gfx_8cpp.html#a580ce1d1be3c10f10e279c628d5e7a5e", null ],
    [ "LoadStringWidthTable", "de/da1/gfx_8cpp.html#a62ff1c222d23d5fc80ea9d24ddc25edc", null ],
    [ "MakePolygonSegments", "de/da1/gfx_8cpp.html#a2d5d6aed4e26a82a497fc63d89f55812", null ],
    [ "MarkWholeScreenDirty", "d5/d48/group__dirty.html#ga94c77ddf45ec98384625cba512034f24", null ],
    [ "RedrawScreenRect", "d5/d48/group__dirty.html#gaa02472750c233df959585e724fba4f3b", null ],
    [ "ScreenSizeChanged", "de/da1/gfx_8cpp.html#ac686351aa68925988c7537e19ec2cfef", null ],
    [ "SetAnimatedMouseCursor", "de/da1/gfx_8cpp.html#ab60eb5eb0a0ae49d3fb1a868faf85d34", null ],
    [ "SetColourRemap", "de/da1/gfx_8cpp.html#a46de37429ce642a83f42e90baed0d28e", null ],
    [ "SetCursorSprite", "de/da1/gfx_8cpp.html#a0bd1ab0850cbf41f4d9ee48d8b3c9548", null ],
    [ "SetMouseCursor", "de/da1/gfx_8cpp.html#a0811d7d737e294a66db123e186af6ca0", null ],
    [ "SetMouseCursorBusy", "de/da1/gfx_8cpp.html#a607951b4f6911cdaa8d38b14d4c07c78", null ],
    [ "SortResolutions", "de/da1/gfx_8cpp.html#acf6b1205cbb04e2959540ee14520d8d2", null ],
    [ "SwitchAnimatedCursor", "de/da1/gfx_8cpp.html#afa772a8747496fc2e38cefe3bffd0bde", null ],
    [ "ToggleFullScreen", "de/da1/gfx_8cpp.html#a6c3d71aef57b8889c19026e91f0d4e2d", null ],
    [ "UndrawMouseCursor", "de/da1/gfx_8cpp.html#a0d13104b28e8889179ecb96896f6e1a5", null ],
    [ "UpdateCursorSize", "de/da1/gfx_8cpp.html#a0ba5acdd2730490e8ea3f8485854dfe9", null ],
    [ "_colour_gradient", "de/da1/gfx_8cpp.html#a04e67e52c36bcf9ad6d879494e6b3e2e", null ],
    [ "_colour_remap_ptr", "de/da1/gfx_8cpp.html#a95af7cf3ee5f77e8428449f648e324f3", null ],
    [ "_ctrl_pressed", "de/da1/gfx_8cpp.html#a449ad8ebe1b8f9b4eda3293236fba396", null ],
    [ "_cur_dpi", "de/da1/gfx_8cpp.html#a29b83a34f3f8b1f99d094cd8f4a9dc30", null ],
    [ "_cur_palette", "de/da1/gfx_8cpp.html#a82b91ff60054612cf4344e43ae7923e2", null ],
    [ "_cursor", "de/da1/gfx_8cpp.html#a7b055b3dc8a5c15896a6ac0f0f6499c2", null ],
    [ "_cursor_backup", "de/da1/gfx_8cpp.html#aafd8913569ba03aaf6fe309d7c8f2375", null ],
    [ "_dirkeys", "de/da1/gfx_8cpp.html#a52f15585b6bfb0944c9e6d2610069623", null ],
    [ "_dirty_block_colour", "de/da1/gfx_8cpp.html#a9d43a3f183315e122cf5258dd4872406", null ],
    [ "_dirty_blocks", "de/da1/gfx_8cpp.html#ab050ce6e94522e5e2a8521e1267d9bd6", null ],
    [ "_dirty_bytes_per_line", "de/da1/gfx_8cpp.html#a3ba304a6116ae401357dee224ba70888", null ],
    [ "_exit_game", "de/da1/gfx_8cpp.html#a7eb0d14ae569ca0992df5214cd0b249c", null ],
    [ "_fast_forward", "de/da1/gfx_8cpp.html#af6d3cc28b3e6a11938d0c828b6c3bb64", null ],
    [ "_font_zoom", "de/da1/gfx_8cpp.html#a4e5de06a46f3d474f68abad5dec9e342", null ],
    [ "_fullscreen", "de/da1/gfx_8cpp.html#af41afe2d8abf7062f7aae1ae5e4dca26", null ],
    [ "_game_mode", "de/da1/gfx_8cpp.html#a5f7525568d0b37fb0b60f52154db6b1b", null ],
    [ "_gui_zoom", "de/da1/gfx_8cpp.html#ae59dec4c34d18c9757b5cab17da7cb94", null ],
    [ "_invalid_rect", "d5/d48/group__dirty.html#ga160b895629d19b4f7b532867d6c5eee8", null ],
    [ "_left_button_clicked", "de/da1/gfx_8cpp.html#a4f91b925a590a5658a6175d77b31c4fd", null ],
    [ "_left_button_down", "de/da1/gfx_8cpp.html#a29528c503a35cad849e24c62ccf54a2f", null ],
    [ "_pause_mode", "de/da1/gfx_8cpp.html#a1954072478034feb4d6b9cc867ce5f6d", null ],
    [ "_right_button_clicked", "de/da1/gfx_8cpp.html#a85547be96d2332331ca3386e66047398", null ],
    [ "_right_button_down", "de/da1/gfx_8cpp.html#aebb077b0ea0663869f537b974ef3c858", null ],
    [ "_screen", "de/da1/gfx_8cpp.html#aee3b2caf656df1c9e875f33841c8cf7f", null ],
    [ "_screen_disable_anim", "de/da1/gfx_8cpp.html#a4c49532bf3116616eab958b49c7cbbc0", null ],
    [ "_shift_pressed", "de/da1/gfx_8cpp.html#a15077a1979b5abe1e4cf850f392d37cb", null ],
    [ "_string_colourremap", "de/da1/gfx_8cpp.html#a77f0c7c5b9db2ee5a4fca2c5d4e8ebee", null ],
    [ "_stringwidth_table", "de/da1/gfx_8cpp.html#ac37ee46cc4d3dbe8eb25f0bd9df74bf9", null ],
    [ "_support8bpp", "de/da1/gfx_8cpp.html#a45bc881191b074f1a65f29bfc14de611", null ],
    [ "_switch_mode", "de/da1/gfx_8cpp.html#aca417dc75c3ef57541db809c4664cf74", null ],
    [ "DIRTY_BLOCK_HEIGHT", "de/da1/gfx_8cpp.html#ad8794f9ea40de26aa84406378dfd4110", null ],
    [ "DIRTY_BLOCK_WIDTH", "de/da1/gfx_8cpp.html#ac416df3b69ab1ab6b0dc0a6af5fd2b70", null ]
];
